@@ -82,7 +82,7 @@ class Query:
         
         query_options = {k:v for k,v in self.args.items() if v}
         assert query_options, "empty query, please add query options"
-        if self.args['name']:
+        if name:
             del self.args['gen'], self.args['ssp']
         self.query = '%20'.join(["%s:%s"%(k,v) for k,v in query_options.items()]).replace("name:",'')
         self.args = query_options
@@ -229,6 +229,7 @@ class Query:
         all_recordings = self.retrieve_meta(recordings_only=True)
         all_recordings = [rec for rec in all_recordings if rec['file']]
         
+        nproc = min(len(all_recordings), nproc)
         recording_packs = list(chunks(all_recordings, nproc))
         
         worker_pool = []
